using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;


using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.CMSHelper;

public partial class CMSAdminControls_FCKeditor_plugins_InsertInlineControls_Default : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        lblAvailableControls.Text = ResHelper.GetString("SelectInlineControlDialog.AvailableControls"); 

        btnOK.Text = ResHelper.GetString("General.OK");

        if (!IsPostBack)
        {
            // fill listbox with inline controls available for the current site
            ReloadControls();
        }
                        
    }


    /// <summary>
    /// Reloads list of available controls.
    /// </summary>
    protected void ReloadControls()
    {

        if (CMSContext.CurrentSite != null)
        {
            // get controls for selected site
            lstControls.DataSource = InlineControlInfoProvider.GetInlineControlsForSite(CMSContext.CurrentSite.SiteID);
            lstControls.DataBind();

            // select and display first control of the list by default
            if (lstControls.Items.Count > 0)
            {
                lstControls.SelectedIndex = 0;
                ReloadControlProperties();
            }
            else
            {
                HideControlParameterName();
            }
        }

    }


    /// <summary>
    /// Reloads selected control displayed properties (name, description, parameter name).
    /// </summary>
    protected void ReloadControlProperties()
    {
        string selectedControlName = lstControls.SelectedValue;

        // get selected control info
        InlineControlInfo control = InlineControlInfoProvider.GetInlineControlInfo(selectedControlName);
        if (control != null)
        {
            lblControlName.Text = control.ControlDisplayName;
            lblControlDescription.Text = control.ControlDescription;

            // hide or display control parameter name textbox
            if (control.ControlParameterName != "")
            {
                DisplayControlParameterName();
                lblControlParametrName.Text = control.ControlParameterName + " : ";
            }
            else
            {
                HideControlParameterName();
            }
        }
        else
        {
            HideControlParameterName();
        }
    }



    /// <summary>
    /// Called when selected control changed - displays selected control properties.
    /// </summary>
    protected void lstControls_SelectedIndexChanged(object sender, EventArgs e)
    {
        ReloadControlProperties();
    }


    /// <summary>
    /// Called when OK button is clicked - sends selected control info back to the FCK editor.
    /// </summary>
    protected void btnOK_Click(object sender, EventArgs e)
    {        
        string result = "";

        if ((lstControls.SelectedValue != null) && (lstControls.SelectedValue != ""))
        {
            result = lstControls.SelectedValue;

            if (txtControlParametrName.Visible)
            {
                // add parameter name
                result += ("?" + txtControlParametrName.Text.Trim());
            }
            
            // get inline control macro
            result = "%%control:" + result + "%%";

            // return macro to the FCK editor
            ltlScript.Text = ScriptHelper.GetScript("InsertUserControl('" + result + "');");
        }
        else
        {   
            // close window
            ltlScript.Text = ScriptHelper.GetScript("window.parent.Cancel();");
        }
    }


    /// <summary>
    /// Hides control parameter name textbox.
    /// </summary>
    protected void HideControlParameterName()
    {
        lblControlParametrName.Visible = false;
        txtControlParametrName.Visible = false;
    }


    /// <summary>
    /// Displays control parameter name textbox.
    /// </summary>
    protected void DisplayControlParameterName()
    {
        lblControlParametrName.Visible = true;
        txtControlParametrName.Visible = true;
    }
}
