using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

using CMS.CMSHelper;
using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.TreeEngine;
using CMS.PortalEngine;

public partial class CMSDesk_PortalEngine_NewPage : CMSDeskPage
{

    protected void Page_Load(object sender, EventArgs e)
    {
        lblPageName.Text = ResHelper.GetString("NewPage.PageName");
        lblTitle.Text = ResHelper.GetString("NewPage.PageTemplateTitle");
        radCreateBlank.Text = ResHelper.GetString("NewPage.CreateBlank");
        radInherit.Text = ResHelper.GetString("NewPage.Inherit");
        radUseTemplate.Text = ResHelper.GetString("NewPage.UseTemplate");
        btnOk.Text = ResHelper.GetString("NewPage.OK");

        // enables options for global administrator, disables it for others
        if (CMSContext.CurrentUser.IsGlobalAdministrator)
        {
            radCreateBlank.Visible = true;
            ucoLayoutSelection.Visible = true;
        }
        else
        {
            radCreateBlank.Visible = false;
            ucoLayoutSelection.Visible = false;
            radCreateBlank.Checked = false;
        }

        radUseTemplate.Attributes.Add("onclick", "ShowSelection();");
        radInherit.Attributes.Add("onclick", "ShowSelection()");
        radCreateBlank.Attributes.Add("onclick", "ShowSelection();");

        ltlScript.Text = ScriptHelper.GetScript("var layoutListbox = document.getElementById('" + ucoLayoutSelection.ClientID + "');");
        ltlScript.Text = ScriptHelper.GetScript("function SaveDocument(nodeId) {" + ClientScript.GetPostBackEventReference(this.btnOk, null) + "; return false; }");
    }


    /// <summary>
    /// Updates node properties in database
    /// </summary>
    protected void btnOk_Click(object sender, EventArgs e)
    {
        string mPageName = txtPageName.Text;
        int rootNodeId = ValidationHelper.GetInteger(Request.QueryString["nodeid"], 0);
        CMS.TreeEngine.TreeNode node = new CMS.TreeEngine.TreeNode("CMS.MenuItem");
        bool ok = true;
        if (mPageName != String.Empty)
        {
            node.DocumentName = mPageName;
        }
        else
        {
            ok = false;
            lblError.Text = ResHelper.GetString("newpage.nameempty");
            lblError.Visible = true;
        }

        node.SetValue("MenuItemName", mPageName);

        // Create new page
        if (radCreateBlank.Checked)
        {
            // Blank page with layout
            int layoutId = this.ucoLayoutSelection.SelectedLayoutId;

            if (layoutId > 0)
            {
                // Create custom template info for the page
                PageTemplateInfo templateInfo = new PageTemplateInfo(true);
                templateInfo.LayoutID = layoutId;
                // Create an ad-hoc one
                templateInfo = PageTemplateInfoProvider.CloneTemplateAsAdHoc(templateInfo);
                if (CMSContext.CurrentSite != null)
                {
                    PageTemplateInfoProvider.AddPageTemplateToSite(templateInfo.PageTemplateId, CMSContext.CurrentSite.SiteID);
                }
                // Assign the template
                node.SetValue("DocumentPageTemplateID", templateInfo.PageTemplateId);
            }
            else
            {
                ok = false;
                lblError.Text = ResHelper.GetString("NewPage.LayoutError");
                lblError.Visible = true;
            }
        }
        else if (radInherit.Checked)
        {
            // Inherited page           
            node.SetValue("DocumentPageTemplateID", DBNull.Value);
        }
        else if (radUseTemplate.Checked)
        {
            // Template page
            int templateId = ucoPageTemplateSelection.SelectedPageTemplateId;
            if (templateId != 0)
            {
                node.DocumentPageTemplateID = templateId;
            }
            else
            {
                ok = false;
                lblError.Text = ResHelper.GetString("NewPage.TemplateError");
                lblError.Visible = true;
            }
        }

        node.DocumentCulture = CMSContext.CurrentUser.PreferredCultureCode;

        // if exist root node, insert new node
        if ((rootNodeId != 0) && ok)
        {
            node.Insert(rootNodeId);
            ltlScript.Text += ScriptHelper.GetScript("RefreshNode(" + node.NodeID + ", " + node.NodeID + ");");
            ltlScript.Text += ScriptHelper.GetScript("SelectNode(" + node.NodeID + ");");
        }
    }
}
