using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;

using System.Web.UI.HtmlControls;
using System.Drawing.Imaging;
using System.Drawing;
using System.IO;

using CMS.FileManager;
using CMS.WorkflowEngine;
using CMS.TreeEngine;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.DataEngine;
using CMS.SiteProvider;
using CMS.SettingsProvider;


public partial class CMSPages_GetFile : System.Web.UI.Page
{
    protected int versionHistoryID = 0;
    protected int width = 0;
    protected int height = 0;
    protected int maxSideSize = 0;
    protected CMSOutputFile outputFile = null;
    protected string useCacheItemName = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        useCacheItemName = this.Context.Request.Url.ToString() + "_" + CMSContext.CurrentUser.PreferredCultureCode;

        // Seek the attachment in cache
        if ((CacheHelper.Contains(useCacheItemName)) && (CacheHelper.CacheEnabled(CMSContext.CurrentSite.SiteName)) && (CMSContext.CurrentUser.ViewMode == ViewModeEnum.LiveSite))
        {
            // Get OutputFile object and process it.
            outputFile = (CMSOutputFile)CacheHelper.GetItem(useCacheItemName);

            // Clear response.
            Response.Cookies.Clear();
            Response.Clear();

            // Prepare response.
            Response.ContentType = outputFile.Attachment.AttachmentMimeType;
            SetDisposition(outputFile.Attachment.AttachmentName, outputFile.Attachment.AttachmentExtension);

            // Do response.
            Response.OutputStream.Write(outputFile.OutputData, 0, outputFile.OutputData.Length);
            Response.End();
        }
        else
        {
            // Get attachment, process it and store it in cache if caching enabled.
            ProcessAttachment();
        }
    }


    /// <summary>
    /// Processes the attachment.
    /// </summary>
    protected void ProcessAttachment()
    {
        Guid guid = ValidationHelper.GetGuid(Request.QueryString["guid"], Guid.Empty);
        Guid nodeguid = ValidationHelper.GetGuid(Request.QueryString["nodeguid"], Guid.Empty);

        versionHistoryID = ValidationHelper.GetInteger(Request.QueryString["versionhistoryid"], 0);
        width = ValidationHelper.GetInteger(Request.QueryString["width"], 0);
        height = ValidationHelper.GetInteger(Request.QueryString["height"], 0);
        maxSideSize = ValidationHelper.GetInteger(Request.QueryString["maxSideSize"], 0);

        // If guid given, process the attachment
        if (guid != Guid.Empty)
        {
            if (versionHistoryID > 0)
            {
                ProcessFile(guid, versionHistoryID);
            }
            else
            {
                ProcessFile(guid);
            }
        }
        else if (nodeguid != Guid.Empty)
        {
            // If node GUID given, process the file
            ProcessNode(nodeguid);
        }
    }


    /// <summary>
    /// Set rate if width is empty and height not or reversely
    /// </summary>
    private void SetRate(int pictureWidth, int pictureHeight)
    {
        if ((pictureWidth == 0) && (pictureHeight == 0))
            return;

        if (width > pictureWidth)
            width = pictureWidth;

        if (height > pictureHeight)
            height = pictureHeight;

        float ratio = 0;

        if ((width > 0) && (height == 0))
        {
            ratio = (float)pictureWidth / (float)width;
            height = (int)((float)pictureHeight / (float)ratio);
        }

        if ((width == 0) && (height > 0))
        {
            ratio = (float)pictureHeight / (float)height;
            width = (int)((float)pictureWidth / (float)ratio);
        }
    }


    /// <summary>
    /// Processes the specified file and returns the data to the output stream
    /// </summary>
    /// <param name="attachmentGuid">Attachment guid.</param>
    protected void ProcessFile(Guid attachmentGuid)
    {
        AttachmentInfo atInfo = null;
        GeneralConnection conn = new GeneralConnection();
        AttachmentManager atManager = new AttachmentManager(conn);

        // Get AttachmentInfo object
        if (CMSContext.CurrentUser.ViewMode != ViewModeEnum.LiveSite)
        {
            // Not livesite mode - get latest version
            TreeProvider tree = new TreeProvider(CMSContext.CurrentUser, conn);
            atInfo = DocumentHelper.GetAttachment(attachmentGuid, tree);
        }
        else
        {
            // Live site mode 
            atInfo = atManager.GetAttachmentInfoWithoutBinary(attachmentGuid, CMSContext.CurrentSite.SiteName);
        }

        if (atInfo != null)
        {
            // clear response
            Response.Cookies.Clear();
            Response.Clear();

            // prepare response
            Response.ContentType = atInfo.AttachmentMimeType;
            SetDisposition(atInfo.AttachmentName, atInfo.AttachmentExtension);

            // Get the data
            byte[] mFile = null;
            if (atInfo.AttachmentBinary != null)
            {
                mFile = atInfo.AttachmentBinary;
            }
            else
            {
                mFile = atManager.GetFile(attachmentGuid, CMSContext.CurrentSite.SiteName);
            }

            if (mFile == null)
            {
                return;
            }

            // If attachment is image, try resize and store it in cache
            if (ImageHelper.IsImage(atInfo.AttachmentExtension))
            {
                mFile = atManager.GetImageThumbnail(attachmentGuid, mFile, atInfo.AttachmentExtension, CMSContext.CurrentSite.SiteName, width, height, maxSideSize);

                // Store image in cache only if caching is enabled and view mode is LiveSite.
                if ((CacheHelper.CacheEnabled(CMSContext.CurrentSite.SiteName)) && (CMSContext.CurrentUser.ViewMode == ViewModeEnum.LiveSite))
                {
                    double cacheMinutes = (double)CacheHelper.CacheImageMinutes(CMSContext.CurrentSite.SiteName);
                    if (cacheMinutes > 0)
                    {
                        // Set OutputFile object.
                        outputFile = new CMSOutputFile(atInfo, mFile);

                        CacheHelper.Add(useCacheItemName, outputFile, null, DateTime.Now.AddMinutes(cacheMinutes), System.Web.Caching.Cache.NoSlidingExpiration);
                    }
                }
            }

            Response.OutputStream.Write(mFile, 0, mFile.Length);
            Response.End();

        }
    }


    /// <summary>
    /// processes the specified document node
    /// </summary>
    /// <param name="nodeGuid">Node GUID</param>
    protected void ProcessNode(Guid nodeGuid)
    {
        string siteName = CMSContext.CurrentSite.SiteName;
        TreeProvider tp = new TreeProvider(CMSContext.CurrentUser);

        TreeNode tn = tp.SelectSingleNode(nodeGuid, TreeProvider.ALL_CULTURES, siteName);
        if (tn != null)
        {
            tn = tp.SelectSingleNode(siteName, tn.NodeAliasPath, CMSContext.CurrentUser.PreferredCultureCode, SettingsKeyProvider.GetBoolValue(siteName + ".CMSCombineWithDefaultCulture"), "CMS.File", false);
            if (tn != null)
            {
                if (tn.NodeClassName.ToLower() == "cms.file")
                {
                    Guid attachmentGuid = ValidationHelper.GetGuid(tn.GetValue("FileAttachment"), Guid.Empty);
                    if (attachmentGuid != Guid.Empty)
                    {
                        ProcessFile(attachmentGuid);
                    }
                }
            }
        }
    }


    /// <summary>
    /// Processes the specified version of the file and returns the data to the output stream
    /// </summary>
    /// <param name="attachmentGuid">Attachment GUID</param>
    /// <param name="versionHistoryId">Document version history ID</param>
    protected void ProcessFile(Guid attachmentGuid, int versionHistoryId)
    {

        CurrentUserInfo ui = CMSContext.CurrentUser;

        if (ui != null)
        {
            AttachmentInfo atInfo = GetFile(attachmentGuid, versionHistoryId);

            if (atInfo != null)
            {
                TreeProvider tp = new TreeProvider();
                TreeNode tn = tp.SelectSingleDocument(atInfo.AttachmentDocumentID);

                if (tn != null)
                {
                    if ((ui.IsAuthorizedPerTreeNode(tn.NodeID, NodePermissionsEnum.Read) != AuthorizationResultEnum.Denied) ||
                         (ui.IsAuthorizedPerResource("cms.content", "read")))
                    {
                        // clear response
                        Response.Cookies.Clear();
                        Response.Clear();

                        // prepare response
                        Response.ContentType = atInfo.AttachmentMimeType;
                        SetDisposition(atInfo.AttachmentName, atInfo.AttachmentExtension);

                        // If attachment is image, try resize
                        byte[] mFile = atInfo.AttachmentBinary;
                        
                        if (mFile == null)
                        {
                            return;
                        }

                        if (ImageHelper.IsImage(atInfo.AttachmentExtension))
                        {
                            GeneralConnection conn = new GeneralConnection();
                            AttachmentManager atManager = new AttachmentManager(conn);

                            mFile = atManager.GetImageThumbnail(attachmentGuid, mFile, atInfo.AttachmentExtension, CMSContext.CurrentSite.SiteName, width, height, maxSideSize);

                            // Store image in cache only if caching is enabled and view mode is LiveSite.
                            if ((CacheHelper.CacheEnabled(CMSContext.CurrentSite.SiteName)) && (CMSContext.CurrentUser.ViewMode == ViewModeEnum.LiveSite))
                            {
                                double cacheMinutes = (double)CacheHelper.CacheImageMinutes(CMSContext.CurrentSite.SiteName);
                                if (cacheMinutes > 0)
                                {
                                    // Set OutputFile object.
                                    outputFile = new CMSOutputFile(atInfo, mFile);

                                    CacheHelper.Add(useCacheItemName, outputFile, null, DateTime.Now.AddMinutes(cacheMinutes), System.Web.Caching.Cache.NoSlidingExpiration);
                                }
                            }
                        }

                        Response.OutputStream.Write(mFile, 0, mFile.Length);
                        Response.End();
                    }
                }
            }
        }
    }


    /// <summary>
    /// 
    /// </summary>
    /// <param name="attachmentHistoryId"></param>
    protected AttachmentInfo GetFile(Guid attachmentGuid, int versionHistoryId)
    {
        TreeProvider tree = new TreeProvider(CMSContext.CurrentUser);
        VersionManager vm = new VersionManager(tree);
        DataClass dc = vm.GetAttachmentVersion(versionHistoryId, attachmentGuid);
        if ((dc == null) || (dc.IsEmpty()))
        {
            return null;
        }
        else
        {
            return new AttachmentInfo(dc.DataRow, tree.Connection);
        }
    }


    /// <summary>
    /// Sets response header according to file type
    /// </summary>
    /// <param name="extension">File extension.</param>
    protected void SetDisposition(string fileName, string extension)
    {
        string disposition = ValidationHelper.GetString(Request.QueryString["disposition"], "");


        // image or html/htm
        if (ImageHelper.IsImage(extension) || ImageHelper.IsHtml(extension))
        {
            // Disposition type - For images "inline" is default
            if (disposition.ToLower() == "attachment")
            {
                Response.AddHeader("Content-Disposition", "attachment; filename=" + FilenameEncode(fileName));
            }
            else
            {
                Response.AddHeader("Content-Disposition", "inline; filename=" + FilenameEncode(fileName));
            }

        }
        // other file type
        else
        {
            // Disposition type - For files "attachment" is default type
            if (disposition.ToLower() == "inline")
            {
                Response.AddHeader("Content-Disposition", "inline; filename=" + FilenameEncode(fileName));
            }
            else
            {
                Response.AddHeader("Content-Disposition", "attachment; filename=" + FilenameEncode(fileName));
            }
        }


    }


    ///<summary>File name enconding function</summary>
    ///<param name="filename">Filename to encode.</param>
    private string FilenameEncode(string filename)
    {
        return HttpUtility.UrlEncode(filename, Response.HeaderEncoding);
    }

}
