using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using CMS.SiteProvider;
using CMS.GlobalHelper;
using CMS.CMSHelper;
using CMS.Scheduler;

public partial class MS2_Project_CMSSolution_Scheduler_Task_List : AdministrationPage
{
    protected string siteName = "";
    protected int siteId = 0;
    protected SiteInfo si = null;

    protected void Page_Load(object sender, EventArgs e)
    {
        this.btnRestart.Text = ResHelper.GetString("Task_List.Restart");

        // control initialization
        HyperlinkNew.Text = ResHelper.GetString("Task_List.NewItemCaption");
        HyperlinkRefresh.Text = ResHelper.GetString("Task_List.Refresh");
        lblSites.Text = ResHelper.GetString("Task_List.SiteSelection");

        UniGridRoles.GridView.GridLines = GridLines.Horizontal;
        UniGridRoles.OnAction += new OnActionEventHandler(UniGridRoles_OnAction);

        PageTitle.TitleText = ResHelper.GetString("Task_List.HeaderCaption");
        PageTitle.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Administration/ScheduledTasks/tasks.gif";

        ImageNew.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Administration/ScheduledTasks/addtask.gif";
        ImageRefresh.ImageUrl = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Administration/ScheduledTasks/refresh.gif";


        if ((Request.QueryString["siteid"] != null) && (Request.QueryString["siteid"].ToString() != ""))
        {
            siteId = Convert.ToInt32(Request.QueryString["siteid"]);
            PanelSites.Visible = false;
            //DropDownListSites.Enabled = false;
        }
        else
        {
            if (!IsPostBack)
            {
                // initializes dropdownlist
                InitializeDropDownListSites();
                int selectedsiteid = 0;
                if ((Request.QueryString["selectedsiteid"] != null) && (Request.QueryString["selectedsiteid"].ToString() != ""))
                {
                    selectedsiteid = Convert.ToInt32(Request.QueryString["selectedsiteid"]);
                }

                if (selectedsiteid > 0)
                {
                    DropDownListSites.SelectedValue = selectedsiteid.ToString();
                }
                else
                {
                    if (DropDownListSites.SelectedIndex > -1)
                    {
                        DropDownListSites.SelectedIndex = 0;
                    }
                }
            }

            if (DropDownListSites.SelectedIndex > -1)
            {
                siteId = Convert.ToInt32(DropDownListSites.SelectedItem.Value);
            }
        }

        if (siteId > 0)
        {
            UniGridRoles.WhereCondition = "TaskSiteID = " + siteId;
            si = SiteInfoProvider.GetSiteInfo(siteId);
            if ( si != null)
            {
                siteName = si.SiteName;
            }
        }
        else
        {
            UniGridRoles.WhereCondition = "TaskSiteID IS NULL";
        }

        if ((Request.QueryString["siteid"] != null) && (Request.QueryString["siteid"] != ""))
        {
            HyperlinkNew.NavigateUrl = "Task_Edit.aspx?siteid=" + siteId;
            HyperlinkRefresh.NavigateUrl = "Task_List.aspx?siteid=" + siteId;
        }
        else
        {
            HyperlinkNew.NavigateUrl = "Task_Edit.aspx?selectedsiteid=" + siteId;
            HyperlinkRefresh.NavigateUrl = "Task_List.aspx?selectedsiteid=" + siteId;
        }        
    }


    /// <summary>
    /// Handles the UniGrid's OnAction event.
    /// </summary>
    /// <param name="actionName">Name of item (button) that threw event.</param>
    /// <param name="actionArgument">ID (value of Primary key) of corresponding data row.</param>
    protected void UniGridRoles_OnAction(string actionName, object actionArgument)
    {
        if (actionName == "edit")
        {
            if ((Request.QueryString["siteid"] != null) && (Request.QueryString["siteid"].ToString() != ""))
            {
                Response.Redirect("Task_Edit.aspx?taskname=" + actionArgument.ToString() + "&siteid=" + siteId.ToString());
            }
            else
            {
                Response.Redirect("Task_Edit.aspx?taskname=" + actionArgument.ToString() + "&selectedsiteid=" + siteId.ToString());
            }
        }

        else if (actionName == "delete")
        {
            TaskInfoProvider.DeleteTaskInfo(Convert.ToInt32(actionArgument));
        }
    }


    /// <summary>
    /// Loads list of sites from DB into DropDownList
    /// </summary>
    protected void InitializeDropDownListSites()
    {
        DataSet dataSetSites = SiteInfoProvider.GetAllSites();
        if ((dataSetSites != null) && (dataSetSites.Tables.Count > 0))
        {
            DataTable dataTableSites = dataSetSites.Tables[0];
            foreach (DataRow dataRowSite in dataTableSites.Rows)
            {
                ListItem listItemSite = new ListItem(dataRowSite["SiteDisplayName"].ToString(), dataRowSite["SiteID"].ToString());
                DropDownListSites.Items.Add(listItemSite);
            }
        }
        if (DropDownListSites.Items.Count > 0) DropDownListSites.SelectedIndex = 0;
    }


    protected override void OnPreRender(EventArgs e)
    {
        if (si != null)
        {
            Object lastRunObj = SchedulingTimer.LastRuns[si.SiteName.ToLower()];
            if (lastRunObj != null)
            {
                DateTime lastRun = (DateTime)lastRunObj;
                if (lastRun != new DateTime(0))
                {
                    this.lblLastRun.Text = ResHelper.GetString("Task_List.LastRun") + " " + lastRun.ToString();
                }
                else
                {
                    this.lblLastRun.Text = ResHelper.GetString("Task_List.NoRun");
                }
            }
            else
            {
                this.lblLastRun.Text = ResHelper.GetString("Task_List.NoRun");
            }
        }

        this.pnlLastRun.Visible = (si != null);
        base.OnPreRender(e);
    }


    protected void btnRestart_Click(object sender, EventArgs e)
    {
        SchedulingTimer.RestartTimer(si.SiteName);
    }
}


