using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;
using CMS.GlobalHelper;
using CMS.SettingsProvider;
using CMS.DataProviderSQL;
using CMS.FormEngine;
using CMS.SiteProvider;
using CMS.TreeEngine;

using CMS.CMSHelper;
using CMS.LicenseProvider;

public partial class SiteManager_Development_DocumentTypes_DocumentType_New : SiteManagerPage
{    

    #region "Private properties"

    /// <summary>
    /// Name of the new created class
    /// </summary>
    private string ClassName
    {
        get
        {
            object obj = ViewState["ClassName"];
            return (obj == null) ? string.Empty : (string)obj;
        }

        set
        {
            ViewState["ClassName"] = value;
        }
    }


    /// <summary>
    /// Indicates whether steps 3 and 4 were omitted or not
    /// </summary>
    private bool SomeStepsOmitted
    {
        get
        {
            object obj = ViewState["SomeStepsOmitted"];
            return (obj == null) ? false : (bool)obj;
        }

        set
        {
            ViewState["SomeStepsOmitted"] = value;
        }
    }

    #endregion


    protected void Page_Load(object sender, EventArgs e)
    {
        if (DataHelper.GetNotEmpty(UrlHelper.GetCurrentDomain(), "") != "")
        {
            LicenseHelper.CheckFeatureAndRedirect(UrlHelper.GetCurrentDomain(), FeatureEnum.CustomDocumentTypes);
        }
        // set controls of the first step
        if (!IsPostBack)
        {
            wzdStep1.EnableViewState = true;
            wzdStep2.EnableViewState = false;
            wzdStep3.EnableViewState = false;
            wzdStep4.EnableViewState = false;
            wzdStep5.EnableViewState = false;
            wzdStep6.EnableViewState = false;
            wzdStep7.EnableViewState = false;

            lblDisplayName.Text = ResHelper.GetString("DocumentType_New.DisplayName");
            lblFullCodeName.Text = ResHelper.GetString("DocumentType_New.FullCodeName");
            lblNamespaceName.Text = ResHelper.GetString("DocumentType_New.NamespaceName");
            lblCodeName.Text = ResHelper.GetString("DocumentType_New.CodeName");

            // set validators' error messages
            rfvDisplayName.ErrorMessage = ResHelper.GetString("DocumentType_New.ErrorEmptyDisplayName");
            rfvCodeName.ErrorMessage = ResHelper.GetString("DocumentType_New.ErrorEmptyCodeName");
            rfvNamespaceName.ErrorMessage = ResHelper.GetString("DocumentType_New.ErrorEmptyNamespaceName");
            revNameSpaceName.ErrorMessage = ResHelper.GetString("DocumentType_New.NamespaceNameIdentificator");
            revCodeName.ErrorMessage = ResHelper.GetString("DocumentType_New.CodeNameIdentificator");

            // sets regular expression for identificator validation
            revNameSpaceName.ValidationExpression = "^([A-Za-z]|_[A-Za-z])\\w*$";
            revCodeName.ValidationExpression = "^([A-Za-z]|_[A-Za-z])\\w*$";

            wzdStep1.Title = ResHelper.GetString("DocumentType_New_Step1.Title");
            lblStepDesc.Text = ResHelper.GetString("DocumentType_New_Step1.Description");
        }
        else
        {
            // disable regular expression validators in next steps
            revNameSpaceName.Enabled = false;
            revCodeName.Enabled = false;
        }

        // for all steps
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = ResHelper.GetString("DocumentType_New.DocumentTypes");
        pageTitleTabs[0, 1] = "~/CMSSiteManager/Development/DocumentTypes/DocumentType_List.aspx";
        pageTitleTabs[0, 2] = "";
        pageTitleTabs[1, 0] = ResHelper.GetString("DocumentType_New.CurrentDocumentType");
        pageTitleTabs[1, 1] = "";
        pageTitleTabs[1, 2] = "";
        pagetitleDocNew.Breadcrumbs = pageTitleTabs;
        pagetitleDocNew.TitleText = ResHelper.GetString("DocumentType_New.Title"); ;
        pagetitleDocNew.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Development/DocumentTypes/newdoctype.gif";

        // set FieldEditor's properties
        FieldEditor.ClassName = ClassName;
        FieldEditor.Mode = FieldEditorModeEnum.ClassFormDefinition;

        // set buttons' text                
        wzdNewDocType.StartNextButtonText = ResHelper.GetString("DocumentType_New.NextButtonText");
        wzdNewDocType.StepNextButtonText = wzdNewDocType.StartNextButtonText;
        wzdNewDocType.FinishCompleteButtonText = ResHelper.GetString("DocumentType_New.FinishButtonText");

    }

    protected void Page_PreRender()
    {
        // set current step title
        lblStepTitle.Text = GetCurrentStepTitle(wzdNewDocType.ActiveStepIndex);
    }

    /// <summary>
    /// 'Next' button is clicked
    /// </summary>
    protected void wzdNewDocType_NextButtonClick(object sender, WizardNavigationEventArgs e)
    {        
        DataClassInfo dci = null;
        FormInfo fi = null;          

        switch (e.CurrentStepIndex)
        {

            // STEP 1
            //---------------------------------------------------------------
            case 0:

                // actions after next button click
                //-----------------------------------------------------------

                // validate checkboxes first
                string errorMessage = new Validator().NotEmpty(txtDisplayName.Text, ResHelper.GetString("DocumentType_New.ErrorEmptyDisplayName")).
                    NotEmpty(txtCodeName.Text, ResHelper.GetString("DocumentType_New.ErrorEmptyCodeName")).
                    NotEmpty(txtNamespaceName.Text, ResHelper.GetString("DocumentType_New.ErrorEmptyNamespaceName")).
                    IsIdentificator(txtCodeName.Text, ResHelper.GetString("DocumentType_New.CodeNameIdentificator")).
                    IsIdentificator(txtNamespaceName.Text, ResHelper.GetString("DocumentType_New.NamespaceNameIdentificator")).Result;                    

                if (errorMessage == "")
                {

                    // set new class info
                    dci = new DataClassInfo();
                    dci.ClassDisplayName = txtDisplayName.Text;
                    dci.ClassName = txtNamespaceName.Text + "." + txtCodeName.Text;
                    dci.ClassIsDocumentType = true;
                    dci.ClassUsePublishFromTo = true;

                    // insert new class into DB                    
                    try
                    {
                        DataClassInfoProvider.SetDataClass(dci);


                        // set default permissions
                        SetPermission(dci.ClassID, "Read", ResHelper.GetString("PermissionNames.Read"));
                        SetPermission(dci.ClassID, "Modify", ResHelper.GetString("PermissionNames.Modify"));
                        SetPermission(dci.ClassID, "Create", ResHelper.GetString("PermissionNames.Create"));
                        SetPermission(dci.ClassID, "Delete", ResHelper.GetString("PermissionNames.Delete"));
                        SetPermission(dci.ClassID, "Destroy", ResHelper.GetString("PermissionNames.Destroy"));
                        SetPermission(dci.ClassID, "ExploreTree", ResHelper.GetString("PermissionNames.ExploreTree"));
                        SetPermission(dci.ClassID, "ModifyPermissions", ResHelper.GetString("PermissionNames.ModifyPermissions"));

                    }
                    catch (Exception ex)
                    {

                        // no movement to the next step
                        e.Cancel = true;

                        // class with the same class name already exists
                        lblErrorStep1.Visible = true;
                        lblErrorStep1.Text = ex.Message;

                    }

                    // prepare next step (2)
                    //-----------------------------------------------------------         
                    if (lblErrorStep1.Text == "")
                    {                              
                        // disable previous steps' viewstates
                        DisablePreviousStepsViewStates(e.CurrentStepIndex);

                        // enable next step's viewstate
                        EnableNextStepViewState(e.CurrentStepIndex);

                        // save ClassName to viewstate to use in the next steps
                        ClassName = dci.ClassName;

                        // prefill textboxes in the next step with default values
                        txtTableName.Text = txtNamespaceName.Text + "_" + txtCodeName.Text;
                        txtPKName.Text = txtCodeName.Text + "ID";

                        // initialize other conrols
                        lblPKName.Text = ResHelper.GetString("DocumentType_New.PrimaryKeyName");
                        lblTableName.Text = ResHelper.GetString("DocumentType_New.TableName");
                        radCustom.Text = ResHelper.GetString("DocumentType_New.Custom");
                        radContainer.Text = ResHelper.GetString("DocumentType_New.Container");
                        wzdStep2.Title = ResHelper.GetString("DocumentType_New_Step2.Title");
                        lblStepDesc.Text = ResHelper.GetString("DocumentType_New_Step2.Description");
                    }
                }
                else
                {
                    // no movement to the next step
                    e.Cancel = true;

                    // textboxes are not filled correctly
                    lblErrorStep1.Visible = true;
                    lblErrorStep1.Text = errorMessage;
                }

                break;


            // STEP 2
            //---------------------------------------------------------------
            case 1:

                FormFieldInfo ffiPrimaryKey = null;
                dci = DataClassInfoProvider.GetDataClass(ClassName);

                if (dci != null)
                {
                    // new document type has custom attributes -> no wizard steps will be omitted
                    if (radCustom.Checked)
                    {
                        // actions after next button click
                        //-------------------------------------------------------

                        // validate checkboxes first
                        string tableNameEmpty = new Validator().NotEmpty(txtTableName.Text, ResHelper.GetString("DocumentType_New.ErrorEmptyTableName")).Result;
                        string primaryKeyNameEmpty = new Validator().NotEmpty(txtPKName.Text, ResHelper.GetString("DocumentType_New.ErrorEmptyPKName")).Result;
                        
                        // textboxes are filled correctly
                        if ((tableNameEmpty == "") && (primaryKeyNameEmpty == ""))
                        {
                            string tableName = txtTableName.Text.Trim();

                            try
                            {
                                // create new table in DB
                                TableManager.CreateTable(tableName, txtPKName.Text.Trim());
                            }
                            catch (Exception ex)
                            {
                                // no movement to the next step
                                e.Cancel = true;

                                // table with the same name already exists
                                lblErrorStep2.Visible = true;
                                lblErrorStep2.Text = ex.Message;
                            }

                            if (lblErrorStep2.Text == "")
                            {
                                // Change table owner                        
                                try
                                {
                                    string owner = SettingsKeyProvider.GetStringValue(CMSContext.CurrentSite.SiteName + ".CMSDBObjectOwner");
                                    if ((owner != "") && (owner.ToLower() != "dbo"))
                                    {
                                        TableManager.ChangeDBObjectOwner(tableName, owner);
                                        tableName = owner + "." + tableName;
                                    }
                                }
                                catch //(Exception ex)
                                {
                                }

                                fi = new FormInfo();
                                ffiPrimaryKey = new FormFieldInfo();

                                // fill FormInfo object
                                ffiPrimaryKey.Name = txtPKName.Text;
                                ffiPrimaryKey.Caption = txtPKName.Text;
                                ffiPrimaryKey.DataType = FormFieldDataTypeEnum.Integer;
                                ffiPrimaryKey.DefaultValue = "";
                                ffiPrimaryKey.Description = "";
                                ffiPrimaryKey.FieldType = FormFieldControlTypeEnum.LabelControl;
                                ffiPrimaryKey.PrimaryKey = true;
                                ffiPrimaryKey.System = false;
                                ffiPrimaryKey.Visible = true;
                                ffiPrimaryKey.Size = 0;
                                ffiPrimaryKey.AllowEmpty = false;

                                // create empty form definition 
                                fi.LoadXmlDefinition("<form></form>");

                                // add field to form definition
                                fi.AddFormField(ffiPrimaryKey);

                                dci.ClassTableName = tableName;
                                dci.ClassXmlSchema = TableManager.GetXmlSchema(dci.ClassTableName);
                                dci.ClassFormDefinition = fi.GetXmlDefinition();
                                dci.ClassIsCoupledClass = true;

                                // update class in DB
                                DataClassInfoProvider.SetDataClass(dci);

                                // remember that no steps were omitted
                                SomeStepsOmitted = false;


                                // prepare next step (3)
                                //-------------------------------------------------------

                                // disable previous steps' viewstates
                                DisablePreviousStepsViewStates(e.CurrentStepIndex);

                                // enable next step's viewstate
                                EnableNextStepViewState(e.CurrentStepIndex);

                                // set field editor class name
                                FieldEditor.ClassName = ClassName;

                                // fill field editor in the next step
                                FieldEditor.Reload(null);

                                wzdStep3.Title = ResHelper.GetString("DocumentType_New_Step3.Title");
                                lblStepDesc.Text = ResHelper.GetString("DocumentType_New_Step3.Description");

                            }
                        }
                        // some textboxes are not filled correctly
                        else
                        {
                            // prepare current step (2)
                            //-------------------------------------------------------

                            // no movement to the next step
                            e.Cancel = true;

                            // show errors
                            lblTableNameError.Text = tableNameEmpty;
                            lblPKNameError.Text = primaryKeyNameEmpty;

                            wzdStep2.Title = ResHelper.GetString("DocumentType_New_Step2.Title");
                            lblStepDesc.Text = ResHelper.GetString("DocumentType_New_Step2.Description");

                        }
                    }
                    // new document type is only the container -> some wizard steps will be omitted
                    else
                    {
                        // actions after next button click
                        //-------------------------------------------------------

                        dci.ClassIsCoupledClass = false;

                        // update class in DB
                        DataClassInfoProvider.SetDataClass(dci);

                        // remember that some steps were omitted
                        SomeStepsOmitted = true;


                        // prepare next step (5) - skip steps 3 and 4
                        //-------------------------------------------------------

                        // disable previous steps' viewstates
                        DisablePreviousStepsViewStates(3);

                        // enable next step's viewstate
                        EnableNextStepViewState(3);

                        PrepareStep5();
                        wzdNewDocType.ActiveStepIndex = 4;  // go to the step 5 (counted from 0)                        
                    }

                    // create new icon
                    string sourceFile = "";
                    string destFile = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Icons/" + ClassName.Replace(".", "_") + ".gif";

                    if (SomeStepsOmitted) // if class is not coupled class
                    {
                        sourceFile = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Icons/defaultcontainer.gif";
                    }
                    else
                    {
                        sourceFile = "~/App_Themes/" + this.Theme + "/Images/CMSDesk/Icons/default.gif";
                    }

                    if (!File.Exists(Server.MapPath(destFile)))
                    {
                        try
                        {
                            // create new document type icon via copying default icon
                            File.Copy(Server.MapPath(sourceFile), Server.MapPath(destFile), false);
                        }
                        catch
                        {
                            lblErrorStep3.Visible = true;
                            lblErrorStep3.Text = string.Format(ResHelper.GetString("DocumentType_New_Step2.ErrorCopyIcon"), sourceFile, destFile);
                        }
                    }

                }
                break;
            

            // STEP 3
            //---------------------------------------------------------------
            case 2:                

                // actions after next button click
                //-----------------------------------------------------------

                    //generate basic queries
                    SqlGenerator.GenerateQuery(ClassName, "select", SqlOperationTypeEnum.SelectQuery, false);
                    SqlGenerator.GenerateQuery(ClassName, "delete", SqlOperationTypeEnum.DeleteQuery, false);
                    SqlGenerator.GenerateQuery(ClassName, "insert", SqlOperationTypeEnum.InsertQuery, true);
                    SqlGenerator.GenerateQuery(ClassName, "update", SqlOperationTypeEnum.UpdateQuery, false);
                    SqlGenerator.GenerateQuery(ClassName, "selectall", SqlOperationTypeEnum.SelectAll, false);
                    SqlGenerator.GenerateQuery(ClassName, "searchtree", SqlOperationTypeEnum.SearchTree, false);
                    SqlGenerator.GenerateQuery(ClassName, "selectdocuments", SqlOperationTypeEnum.SelectDocuments, false);
                    SqlGenerator.GenerateQuery(ClassName, "selectversions", SqlOperationTypeEnum.SelectVersions, false);

                // prepare next step (4)
                //-----------------------------------------------------------

                // disable previous steps' viewstates
                DisablePreviousStepsViewStates(e.CurrentStepIndex);

                // enable next step's viewstate
                EnableNextStepViewState(e.CurrentStepIndex);

                fi = new FormInfo();                
                FormFieldInfo[] ffiVisibleFields = null;

                // get and load form definition
                string formDef = DataClassInfoProvider.GetDataClass(ClassName).ClassFormDefinition;
                fi.LoadXmlDefinition(formDef);

                // get all visible fields
                ffiVisibleFields = fi.GetVisibleFields();

                // add implicit value to the list
                lstFields.Items.Add(new ListItem(ResHelper.GetString("DocumentType_New_Step4.ImplicitDocumentName"), ""));

                if (ffiVisibleFields != null)
                {
                    // add visible fields' names to the list
                    foreach (FormFieldInfo ffi in ffiVisibleFields)
                    {
                        lstFields.Attributes.Add(ffi.Name, ffi.Name);
                        lstFields.Items.Add(new ListItem(ffi.Name, ffi.Name));
                    }                    
                }

                lblSelectField.Text = ResHelper.GetString("DocumentType_New_Step4.DocumentName");
                wzdStep4.Title = ResHelper.GetString("DocumentType_New_Step4.Title");
                lblStepDesc.Text = ResHelper.GetString("DocumentType_New_Step4.Description");

                break;


            // STEP 4
            //---------------------------------------------------------------
            case 3:

                // actions after next button click
                //-----------------------------------------------------------

                dci = DataClassInfoProvider.GetDataClass(ClassName);
                dci.ClassNodeNameSource = lstFields.SelectedValue;

                // update node name source in DB
                DataClassInfoProvider.SetDataClass(dci);


                // prepare next step (5)
                //-----------------------------------------------------------

                // disable previous steps' viewstates
                DisablePreviousStepsViewStates(e.CurrentStepIndex);

                // enable next step's viewstate
                EnableNextStepViewState(e.CurrentStepIndex);

                PrepareStep5();                

                break;


            // STEP 5
            //---------------------------------------------------------------
            case 4:

                // actions after next button click
                //-----------------------------------------------------------

                int parentClassID = 0;
                int childClassID = DataClassInfoProvider.GetDataClass(ClassName).ClassID;
                bool isCheckedClass = false;

                // go through the gridview rows
                for (int i = 0; i < gvChildTypes.Rows.Count; i++)
                {                    
                    parentClassID = Convert.ToInt32(gvChildTypes.Rows[i].Cells[3].Text);
                    isCheckedClass = ((CheckBox)gvChildTypes.Rows[i].FindControl("chkSelect")).Checked;

                    // if checkbox is checked, child class can be placed under parent class
                    if (isCheckedClass)
                    {
                        DataClassInfoProvider.AllowChildClass(parentClassID, childClassID);
                    }
                }

                // prepare next step (6)
                //-----------------------------------------------------------

                // disable previous steps' viewstates
                DisablePreviousStepsViewStates(e.CurrentStepIndex);

                // enable next step's viewstate
                EnableNextStepViewState(e.CurrentStepIndex);

                // initialize labels                
                gvSites.Columns[0].HeaderText = ResHelper.GetString("DocumentType_New_Step6.Select");
                gvSites.Columns[1].HeaderText = ResHelper.GetString("DocumentType_New_Step6.SiteName");
                wzdStep6.Title = ResHelper.GetString("DocumentType_New_Step6.Title");
                lblStepDesc.Text = ResHelper.GetString("DocumentType_New_Step6.Description");

                // read all sites to gridview
                DataSet dsSites = SiteInfoProvider.GetAllSites();
                gvSites.DataSource = dsSites.Tables[0];

                gvSites.Columns[2].Visible = true;
                gvSites.DataBind();
                gvSites.Columns[2].Visible = false;

                gvSites.GridLines = GridLines.Horizontal;

                break;


            // STEP 6
            //---------------------------------------------------------------
            case 5:

                // actions after next button click
                //-----------------------------------------------------------

                int siteId = 0;                
                int classId = DataClassInfoProvider.GetDataClass(ClassName).ClassID;
                bool isCheckedSite = false;

                // go through the gridview rows
                for (int i = 0; i < gvSites.Rows.Count; i++)
                {                    
                    siteId = Convert.ToInt32(gvSites.Rows[i].Cells[2].Text);
                    isCheckedSite = ((CheckBox)gvSites.Rows[i].FindControl("chkSelect")).Checked;

                    // if checkbox is checked, class is added to specific site
                    if (isCheckedSite)
                    {
                        DataClassInfoProvider.AddClassToSite(classId, siteId);
                    }
                }


                if (SomeStepsOmitted) // if class is not coupled class - > generete some queries
                {   

                    SetQuery(classId, "searchtree", SqlOperationTypeEnum.SearchTree);
                    SetQuery(classId, "selectdocuments", SqlOperationTypeEnum.SelectDocuments);
                    SetQuery(classId, "selectversions", SqlOperationTypeEnum.SelectVersions);
                }
                else // if class is coupled class -> set transformation
                {

                    // create default transformation
                    TransformationInfo ti = new TransformationInfo();
                    ti.TransformationName = ResHelper.GetString("TransformationName.Default");
                    ti.TransformationFullName = ClassName + "." + ti.TransformationName;
                    ti.TransformationCode = TransformationInfoProvider.GenerateTransformationCode(DataClassInfoProvider.GetDataClass(ClassName).ClassFormDefinition, TransformationTypeEnum.Ascx, ClassName);
                    ti.TransformationType = TransformationTypeEnum.Ascx;
                    ti.TransformationClassID = classId;

                    // set default transformation in DB
                    TransformationInfoProvider.SetTransformation(ti);

                }

                // prepare next step (7) - Finish step
                //-----------------------------------------------------------

                // disable previous steps' viewstates
                DisablePreviousStepsViewStates(e.CurrentStepIndex);

                // enable next step's viewstate
                EnableNextStepViewState(e.CurrentStepIndex);

                lblStepDesc.Visible = false;
                wzdStep7.Title = ResHelper.GetString("DocumentType_New_Step7.Title");
                lblInfoStep7.Text = ResHelper.GetString("DocumentType_New_Step7.Info");
                

                lblDocumentCreated.Text = ResHelper.GetString("DocumentType_New_Step7_Finished.DocumentCreated");
                lblTableCreated.Text = ResHelper.GetString("DocumentType_New_Step7_Finished.TableCreated");
                lblEditingFormCreated.Text = ResHelper.GetString("DocumentType_New_Step7_Finished.EditingFormCreated");
                lblChildTypesAdded.Text = ResHelper.GetString("DocumentType_New_Step7_Finished.ChildTypesAdded");
                lblSitesSelected.Text = ResHelper.GetString("DocumentType_New_Step7_Finished.SitesSelected");
                lblTransformationCreated.Text = ResHelper.GetString("DocumentType_New_Step7_Finished.TransformationCreated");
                lblPermissionNameCreated.Text = ResHelper.GetString("DocumentType_New_Step7_Finished.PermissionNameCreated");
                lblDefaultIconCreated.Text = ResHelper.GetString("DocumentType_New_Step7_Finished.DefaultIconCreated");


                if (SomeStepsOmitted)
                {
                    lblTableCreated.Visible = false;                    
                }

                break;

        }
    }


    /// <summary>
    /// 'Finish' button is clicked
    /// </summary>
    protected void wzdNewDocType_FinishButtonClick(object sender, EventArgs e)
    {
        // redirect to the document type edit site
        Response.Redirect("~/CMSSiteManager/Development/DocumentTypes/DocumentType_Edit.aspx?documenttypeid=" + DataClassInfoProvider.GetDataClass(ClassName).ClassID);
    }


    /// <summary>
    /// Prepares and fills controls in the step 5
    /// </summary>
    private void PrepareStep5()
    {
        // initialize labels
        gvChildTypes.Columns[0].HeaderText = ResHelper.GetString("DocumentType_New_Step5.Select");
        gvChildTypes.Columns[1].HeaderText = ResHelper.GetString("DocumentType_New_Step5.DisplayName");
        gvChildTypes.Columns[2].HeaderText = ResHelper.GetString("DocumentType_New_Step5.CodeName");
        wzdStep5.Title = ResHelper.GetString("DocumentType_New_Step5.Title");
        lblStepDesc.Text = ResHelper.GetString("DocumentType_New_Step5.Description"); 

        // reads document types to gridview
        DataSet dsDocTypes = SqlHelperClass.ExecuteQuery("Proc_CMS_Class_SelectDocumentTypes", null, QueryTypeEnum.StoredProcedure);
        gvChildTypes.DataSource = dsDocTypes.Tables[0];

        gvChildTypes.Columns[3].Visible = true;
        gvChildTypes.DataBind();
        gvChildTypes.Columns[3].Visible = false;

        gvChildTypes.GridLines = GridLines.Horizontal;
        
    }


    /// <summary>
    /// Disable Viewstates of the current and previous steps
    /// </summary>
    /// <param name="actualViewState">Current step</param>
    private void DisablePreviousStepsViewStates(int currentStep)
    {
        switch (currentStep)
        {
            // step 1
            case 0:
                wzdStep1.EnableViewState = false; 
                break;

            // step 2
            case 1:
                wzdStep1.EnableViewState = false;
                wzdStep2.EnableViewState = false; 
                break;

            // step 3
            case 2:
                wzdStep1.EnableViewState = false;  
                wzdStep2.EnableViewState = false;
                wzdStep3.EnableViewState = false; 
                break;

            // step 4
            case 3:
                wzdStep1.EnableViewState = false;
                wzdStep2.EnableViewState = false;
                wzdStep3.EnableViewState = false;
                wzdStep4.EnableViewState = false; 
                break;

            // step 5
            case 4:
                wzdStep1.EnableViewState = false;
                wzdStep2.EnableViewState = false;
                wzdStep3.EnableViewState = false;
                wzdStep4.EnableViewState = false;
                wzdStep5.EnableViewState = false; 
                break;

            // step 6
            case 5:
                wzdStep1.EnableViewState = false;
                wzdStep2.EnableViewState = false;
                wzdStep3.EnableViewState = false;
                wzdStep4.EnableViewState = false;
                wzdStep5.EnableViewState = false;
                wzdStep6.EnableViewState = false; 
                break;

            // step 7
            case 6:
                wzdStep1.EnableViewState = false;
                wzdStep2.EnableViewState = false;
                wzdStep3.EnableViewState = false;
                wzdStep4.EnableViewState = false;
                wzdStep5.EnableViewState = false;
                wzdStep6.EnableViewState = false;
                wzdStep7.EnableViewState = false; 
                break;

        }
        
    }


    /// <summary>
    /// Enable Viewstate of the next step
    /// </summary>
    /// <param name="actualViewState">Actual step</param>
    private void EnableNextStepViewState(int actualStep)
    {

        switch (actualStep)
        {
            case 0:
                wzdStep2.EnableViewState = true;
                break;

            case 1:
                wzdStep3.EnableViewState = true;
                break;

            case 2:
                wzdStep4.EnableViewState = true;
                break;

            case 3:
                wzdStep5.EnableViewState = true;
                break;

            case 4:
                wzdStep6.EnableViewState = true;
                break;

            case 5:
                wzdStep7.EnableViewState = true;
                break;
        }

    }

    /// <summary>
    /// Returns title of the current step
    /// </summary>
    /// <param name="currentStep">Current step index (counted from 0)</param>
    private string GetCurrentStepTitle(int currentStep)
    {
        string currentStepTitle = "";        

        switch (currentStep)
        {
            case 0:
                currentStepTitle = wzdStep1.Title;
                break;

            case 1:
                currentStepTitle = wzdStep2.Title;
                break;

            case 2:
                currentStepTitle = wzdStep3.Title;
                break;

            case 3:
                currentStepTitle = wzdStep4.Title;
                break;

            case 4:
                currentStepTitle = wzdStep5.Title;
                break;

            case 5:
                currentStepTitle = wzdStep6.Title;
                break;

            case 6:
                currentStepTitle = wzdStep7.Title;
                break;

        }

        return currentStepTitle;
               
    }


    /// <summary>
    /// Set default permission for the new class
    /// </summary>
    /// <param name="classId">Class Id.</param>
    /// <param name="permissionName">Permission name.</param>
    /// <param name="permissionDisplayName">Permission display name.</param>
    protected void SetPermission(int classId, string permissionName, string permissionDisplayName)
    {

        // create default permission
        PermissionNameInfo pi = new PermissionNameInfo();
        pi.PermissionName = permissionName;
        pi.PermissionDisplayName = permissionDisplayName;
        pi.ResourceId = 0; // null
        pi.ClassId = classId;

        // set default permission in DB
        PermissionNameInfoProvider.SetPermissionInfo(pi);
       
    }

    /// <summary>
    /// Set additional query for the new class
    /// </summary>
    /// <param name="classId">Class Id.</param>
    /// <param name="queryName">Query name.</param>
    /// <param name="queryType">Query type.</param>
    protected void SetQuery(int classId, string queryName, SqlOperationTypeEnum queryType)
    {
        // create new query
        Query q = new Query();
        q.QueryName = queryName;
        q.QueryClassId = classId;
        q.QueryType = QueryTypeEnum.SQLQuery;
        q.QueryText = SqlGenerator.GetSqlQuery(DataClassInfoProvider.GetDataClass(classId).ClassName, queryType);
        QueryProvider.SetQuery(q);
        
    }
}
