using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.ImportExport;
using CMS.SiteProvider;
using CMS.CMSHelper;
using CMS.SettingsProvider;

public partial class CMSSiteManager_Sites_Export_ExportSettingsWizard_ExportSettingsWizard : System.Web.UI.UserControl
{
    #region Properties
    /// <summary>
    /// Export settings stored in viewstate
    /// </summary>
    public SiteExportSettings ExportSettings
    {
        get
        {
            if (ViewState["settings"] == null)
            {
                //throw new Exception("[ExportSettingsWizard]: ExportSettings propety not initialised!");
                ViewState["settings"] = new SiteExportSettings();
            }
            return (SiteExportSettings)ViewState["settings"];
        }
        set
        {
            ViewState["settings"] = value;
        }
    }

    #endregion


    protected void Page_Load(object sender, EventArgs e)
    {
        wzdExportSettings.PreviousButtonClick += new WizardNavigationEventHandler(wzdExportSettings_PreviousButtonClick);
        wzdExportSettings.FinishButtonClick += new WizardNavigationEventHandler(wzdExportSettings_FinishButtonClick);
        if (!IsPostBack)
        {
            wzdExportSettings.StartNextButtonText = ResHelper.GetString("ExportSiteSettings.NextStep");
            wzdExportSettings.StepNextButtonText = ResHelper.GetString("ExportSiteSettings.NextStep");
            wzdExportSettings.StepPreviousButtonText = ResHelper.GetString("ExportSiteSettings.PreviousStep");
            wzdExportSettings.FinishCompleteButtonText = ResHelper.GetString("ExportSiteSettings.Finish");

            lblStepDesc.Text = string.Format(ResHelper.GetString("ExportSiteSettings.Step.wizardIntro"), MapPath(ExportProvider.EXPORT_PATH));


            wzdExportSettings.ActiveStepIndex = 0;

            // First step caption
            lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.StepFileSelection.lblStepFileSelection");
        }
    }

    void wzdExportSettings_FinishButtonClick(object sender, WizardNavigationEventArgs e)
    {
        Response.Redirect("~/CMSSiteManager/Sites/site_list.aspx");
    }

    void wzdExportSettings_PreviousButtonClick(object sender, WizardNavigationEventArgs e)
    {
        LoadData(e.CurrentStepIndex - 1);
    }

    protected void wzdExportSettings_NextButtonClick(object sender, WizardNavigationEventArgs e)
    {
        lblError.Visible = false;

        // handles wizards steps
        switch (e.CurrentStepIndex)
        {
            case 0:
                ExportSettings.TargetFileName = ucFileSelection.FileName;
                if (ExportSettings.TargetFileName == "")
                {
                    lblError.Visible = true;
                    lblError.Text = ResHelper.GetString("ExportSiteSettings.StepFileSelection.EnterFileName");
                    e.Cancel = true;
                }
                else if (File.Exists(HttpContext.Current.Server.MapPath(ExportProvider.EXPORT_PATH + ExportSettings.TargetFileName)))
                {
                    lblError.Visible = true;
                    lblError.Text = string.Format(ResHelper.GetString("ExportSiteSettings.StepFileSelection.FileNameExists"), ExportSettings.TargetFileName, ExportProvider.EXPORT_PATH);
                    e.Cancel = true;
                }
                LoadData(e.CurrentStepIndex + 1);
                break;
            // Css styles and create site skeleton
            case 1:
                // Fill selected objects for the export provider
                ExportSettings.SelectedCssStyles = ucCssStyles.GetSelectedObjects();
                LoadData(e.CurrentStepIndex + 1);
                break;
            // Page templates
            case 2:
                // Fill selected objects for the export provider
                ExportSettings.SelectedPageTemplates = ucPageTemplates.GetSelectedObjects();
                ExportSettings.SelectedLayouts = ucLayouts.GetSelectedObjects();
                LoadData(e.CurrentStepIndex + 1);
                break;
            // Document types
            case 3:
                // Fill selected objects for the export provider
                ExportSettings.SelectedDocumentTypes = ucDocTypes.GetSelectedObjects();
                LoadData(e.CurrentStepIndex + 1);
                break;
            // Users
            case 4:
                // Fill selected objects for the export provider
                ExportSettings.SelectedUsers = ucUsers.GetSelectedObjects();
                LoadData(e.CurrentStepIndex + 1);
                break;
            // Webparts
            case 5:
                // Fill selected objects for the export provider
                ExportSettings.SelectedWebParts = ucWebParts.GetSelectedObjects();
                LoadData(e.CurrentStepIndex + 1);
                break;
            // Webpart containers
            case 6:
                // Fill selected objects for the export provider
                ExportSettings.SelectedWebPartContainers = ucWebPartContainers.GetSelectedObjects();
                LoadData(e.CurrentStepIndex + 1);
                break;
            // Form user controls
            case 7:
                // Fill selected objects for the export provider
                ExportSettings.SelectedFormUserControls = ucFormUserCtrls.GetSelectedObjects();
                LoadData(e.CurrentStepIndex + 1);
                break;
            // Inline controls
            case 8:
                // Fill selected objects for the export provider
                ExportSettings.SelectedInlineControls = ucInlineCtrls.GetSelectedObjects();

                ExportSettings.ExportSelected = true;
                if (ExportSettings.ExportTable.Count == 0)
                {
                    if (ExportSettings.SelectedDocumentTypes.Length != 0)
                    {
                        ExportSettings.AddToExportTable("Data/documenttypes.xml", ExportSchema.DOCUMENTTYPES_XML);
                    }
                    if (ExportSettings.SelectedUsers.Length != 0)
                    {
                        ExportSettings.AddToExportTable("Data/users.xml", ExportSchema.USERS_XML);
                    }
                    if ((ExportSettings.SelectedPageTemplates.Length != 0) || (ExportSettings.SelectedLayouts.Length != 0))
                    {
                        ExportSettings.AddToExportTable("Data/pagetemplates.xml", ExportSchema.PAGETEMPLATES_XML);
                    }
                    if ((ExportSettings.SelectedWebParts.Length != 0) || (ExportSettings.SelectedWebPartContainers.Length != 0))
                    {
                        ExportSettings.AddToExportTable("Data/webparts.xml", ExportSchema.WEBPARTS_XML);
                    }
                    if (ExportSettings.SelectedFormUserControls.Length != 0)
                    {
                        ExportSettings.AddToExportTable("Data/formusercontrols.xml", ExportSchema.FORMUSERCONTROLS_XML);
                    }
                    if (ExportSettings.SelectedCssStyles.Length != 0)
                    {
                        ExportSettings.AddToExportTable("Data/cssstylesheets.xml", ExportSchema.CSSSTYLESHEETS_XML);
                    }
                    if (ExportSettings.SelectedInlineControls.Length != 0)
                    {
                        ExportSettings.AddToExportTable("Data/inlinecontrols.xml", ExportSchema.INLINECONTROLS_XML);
                    }
                }
                try
                {
                    // Copy web parts to the temporary files
                    ExportProvider.CopyWebParts(ExportSettings);

                    // Copy form user controls to the temporary files
                    ExportProvider.CopyFormUserControls(ExportSettings);

                    // Copy inline controls to the temporary files
                    ExportProvider.CopyInlineControls(ExportSettings);

                    // Copy skin folders
                    ExportProvider.CopySkinFolders(ExportSettings);

                    if (ExportProvider.ExportSite(ExportSettings, null))
                    {
                        lblResult.Text = string.Format(ResHelper.GetString("ExportSiteSettings.ExportFinished"), MapPath(ExportProvider.EXPORT_PATH) + ExportSettings.TargetFileName);
                    }
                    else
                    {
                        lblResult.Text = ResHelper.GetString("ExportSiteSettings.ExportFinishedNoData");
                    }
                }
                catch (Exception ex)
                {
                    lblError.Visible = true;
                    lblError.Text = string.Format(ResHelper.GetString("ImportExportProvider.DetailedError"), ex.Message, ex.StackTrace);
                    e.Cancel = true;
                }
                finally
                {
                    try
                    {
                        ExportProvider.DeleteTemporaryFiles();
                    }
                    catch (TemporaryFilesDeletionException ex)
                    {
                        lblError.Visible = true;
                        if (lblError.Text != "")
                        {
                            lblError.Text += "<br/>" + ex.Message;
                        }
                        else
                        {
                            lblError.Text = ex.Message;
                        }
                    }
                }
                LoadData(e.CurrentStepIndex + 1);
                break;
            default:
                break;
        }

    }


    private void LoadData(int stepIndex)
    {
        lblStepDesc.Visible = false;
        lblStepDesc.Text = ResHelper.GetString("ExportSiteSettings.Step.lblAsteriskExplanation");

        switch (stepIndex)
        {
            case 0:
                lblStepDesc.Visible = true;
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.StepFileSelection.lblStepFileSelection");
                lblStepDesc.Text = string.Format(ResHelper.GetString("ExportSiteSettings.Step.wizardIntro"), MapPath(ExportProvider.EXPORT_PATH));
                break;
            // Load data for stylesheets selection step
            case 1:
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.wzdStepCssStyles.lblStepCssStyles");

                ucCssStyles.LabelCaption = ResHelper.GetString("ExportSiteSettings.wzdStepCssStyles.lblCssStyles");
                ucCssStyles.LabelNoDataCaption = ResHelper.GetString("ExportSiteSettings.wzdStepCssStyles.noCssStyles");
                ucCssStyles.FirstBoundField = "StylesheetDisplayName";
                ucCssStyles.SecondBoundField = "StylesheetName";
                ucCssStyles.CheckBoxClass = "css";
                ucCssStyles.DataSet = ExportProvider.GetDataSet(Tags.CSSSTYLESHEETS_TAG);
                ucCssStyles.Bind();
                break;
            // Load data for page templates
            case 2:
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.wzdStepPageTemplates.lblStepPageTemplates");

                // Data bind page templates
                ucPageTemplates.LabelCaption = ResHelper.GetString("ExportSiteSettings.wzdStepPageTemplates.lblPageTemplates");
                ucPageTemplates.LabelNoDataCaption = ResHelper.GetString("ExportSiteSettings.wzdStepPageTemplates.noPageTemplates");
                ucPageTemplates.FirstBoundField = "PageTemplateDisplayName";
                ucPageTemplates.SecondBoundField = "PageTemplateCodeName";
                ucPageTemplates.CheckBoxClass = "pt";
                ucPageTemplates.DataSet = ExportProvider.GetDataSet(Tags.PAGETEMPLATES_TAG);
                ucPageTemplates.Bind();

                // Data bind layouts
                ucLayouts.LabelCaption = ResHelper.GetString("ExportSiteSettings.wzdStepPageTemplates.lblLayouts");
                ucLayouts.LabelNoDataCaption = ResHelper.GetString("ExportSiteSettings.wzdStepPageTemplates.noLayouts");
                ucLayouts.FirstBoundField = "LayoutDisplayName";
                ucLayouts.SecondBoundField = "LayoutCodeName";
                ucLayouts.CheckBoxClass = "lay";
                ucLayouts.DataSet = ExportProvider.GetDataSet(Tags.LAYOUTS_TAG);
                ucLayouts.Bind();
                break;
            // Load data for document types
            case 3:
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.wzdStepDocumentTypes.lblStepDocumentTypes");

                // Data bind document types
                ucDocTypes.LabelCaption = ResHelper.GetString("ExportSiteSettings.wzdStepDocumentTypes.lblDocumentTypes");
                ucDocTypes.LabelNoDataCaption = ResHelper.GetString("ExportSiteSettings.wzdStepDocumentTypes.noDocumentTypes");
                ucDocTypes.FirstBoundField = "ClassDisplayName";
                ucDocTypes.SecondBoundField = "ClassName";
                ucDocTypes.CheckBoxClass = "doct";
                ucDocTypes.DataSet = ExportProvider.GetDataSet(Tags.DOCTYPES_TYPES_TAG);
                ucDocTypes.Bind();
                break;
            // Load data for users
            case 4:
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.wzdStepUsers.lblStepUsers");

                // Data bind users
                ucUsers.LabelCaption = ResHelper.GetString("ExportSiteSettings.wzdStepUsers.lblUsers");
                ucUsers.LabelNoDataCaption = ResHelper.GetString("ExportSiteSettings.wzdStepUsers.noUsers");
                ucUsers.FirstBoundField = "FullName";
                ucUsers.SecondBoundField = "UserName";
                ucUsers.CheckBoxClass = "usr";
                ucUsers.DataSet = ExportProvider.GetDataSet(Tags.USERS_TAG);
                ucUsers.Bind();
                break;
            // Load data for webparts
            case 5:
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.wzdStepWebparts.lblStepWebparts");

                // Data bind web parts
                ucWebParts.LabelCaption = ResHelper.GetString("ExportSiteSettings.wzdStepWebparts.lblWebparts");
                ucWebParts.LabelNoDataCaption = ResHelper.GetString("ExportSiteSettings.wzdStepWebparts.noWebparts");
                ucWebParts.FirstBoundField = "WebPartDisplayName";
                ucWebParts.SecondBoundField = "WebPartName";
                ucWebParts.CheckBoxClass = "webp";
                ucWebParts.DataSet = ExportProvider.GetDataSet(Tags.WEBPARTS_TAG);
                ucWebParts.Bind();
                break;
            // Load data for webpart containers
            case 6:
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.wzdStepWebparts.lblStepWebpartContainers");

                // Data bind web parts
                ucWebPartContainers.LabelCaption = ResHelper.GetString("ExportSiteSettings.wzdStepWebparts.lblWebpartContainers");
                ucWebPartContainers.LabelNoDataCaption = ResHelper.GetString("ExportSiteSettings.wzdStepWebparts.noWebpartContainers");
                ucWebPartContainers.FirstBoundField = "ContainerDisplayName";
                ucWebPartContainers.SecondBoundField = "ContainerName";
                ucWebPartContainers.CheckBoxClass = "webc";
                ucWebPartContainers.DataSet = ExportProvider.GetDataSet(Tags.WEBPART_CONTAINERS_TAG);
                ucWebPartContainers.Bind();
                break;
            // Load data for form user controls
            case 7:
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.wzdStepFormUserControls.lblStepFormUserControls");

                // Data bind web parts
                ucFormUserCtrls.LabelCaption = ResHelper.GetString("ExportSiteSettings.wzdStepFormUserControls.lblFormUserControls");
                ucFormUserCtrls.LabelNoDataCaption = ResHelper.GetString("ExportSiteSettings.wzdStepFormUserControls.noFormUserControls");
                ucFormUserCtrls.FirstBoundField = "UserControlDisplayName";
                ucFormUserCtrls.SecondBoundField = "UserControlCodeName";
                ucFormUserCtrls.CheckBoxClass = "fuc";
                ucFormUserCtrls.DataSet = ExportProvider.GetDataSet(Tags.FORMUSERCONTROLS_TAG);
                ucFormUserCtrls.Bind();
                break;
            // Load data for inline controls
            case 8:
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.wzdStepInlineControls.lblStepInlineControls");

                // Data bind web parts
                ucInlineCtrls.LabelCaption = ResHelper.GetString("ExportSiteSettings.wzdStepInlineControls.lblInlineControls");
                ucInlineCtrls.LabelNoDataCaption = ResHelper.GetString("ExportSiteSettings.wzdStepInlineControls.noInlineControls");
                ucInlineCtrls.FirstBoundField = "ControlDisplayName";
                ucInlineCtrls.SecondBoundField = "ControlName";
                ucInlineCtrls.CheckBoxClass = "inc";
                ucInlineCtrls.DataSet = ExportProvider.GetDataSet(Tags.INLINECONTROLS_TAG);
                ucInlineCtrls.Bind();
                break;
            // Load data for the finish step
            case 9:
                lblStepTitle.Text = ResHelper.GetString("ExportSiteSettings.wzdStepFinish.lblStepFinish");
                break;
            default:
                break;
        }
    }


    private void HandleError(Exception ex, WizardNavigationEventArgs e)
    {
        lblError.Visible = true;
        lblError.Text = string.Format(ResHelper.GetString("ImportExportProvider.DetailedError"), ex.Message, ex.StackTrace);
        e.Cancel = true;
    }


    /// <summary>
    /// Handle next button click in the wizard
    /// </summary>
    /// <param name="plcWizard">Placeholder with the wizard</param>
    /// <param name="plcObjectWizard">Placeholder with the ojects wizard</param>
    /// <param name="e">Wizard event argument</param>
    /// <param name="settings">Import settings</param>
    public void HandleNextButtonClick(WizardNavigationEventArgs e, SiteImportSettings settings)
    {
        //if ((!e.Cancel) && (e.NextStepIndex == (StartIndex - 1)))
        //{
        //    // Hide current wizard and display objectswizard
        //    plcWizard.Visible = false;

        //    ExportSettings = settings;
        //    plcObjectWizard.Visible = true;
        //}
    }


    private void HideWizard()
    {
        //this.Parent.Visible = false;
        //Wizard.Parent.Visible = true;
    }

    private void ShowWizard()
    {
        //this.Parent.Visible = true;
        //Wizard.Parent.Visible = false;
    }
}
