using System;
using System.Data;
using System.Configuration;
using System.Collections;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using System.IO;

using CMS.GlobalHelper;
using CMS.SiteProvider;
using CMS.ImportExport;
using CMS.CMSHelper;
using CMS.FileManager;
using CMS.SettingsProvider;
using CMS.DirectoryUtilities;

public partial class SiteManager_Sites_Export_ExportSite : SiteManagerPage
{
    public int siteId = 0;
    public string siteName = "";

    protected void Page_Load(object sender, EventArgs e)
    {
        // If there is no write permission, inform the user
        string rootPath = HttpContext.Current.Server.MapPath("~");
        string exportPath = HttpContext.Current.Server.MapPath(ExportProvider.EXPORT_PATH);
        if (((Directory.Exists(exportPath)) && (!DirectoryHelper.CheckPermissions(exportPath, false, true, true, true))) ||
            ((Directory.Exists(rootPath)) && (!DirectoryHelper.CheckPermissions(rootPath, false, true, true, true))))
        {
            pnlForm.Visible = false;
            lblError.Text = string.Format(ResHelper.GetString("ExportSite.ErrorPermissions"), ExportProvider.EXPORT_PATH);
            this.lnkPermissions.Visible = true;
            this.lnkPermissions.Target = "_blank";
            this.lnkPermissions.Text = ResHelper.GetFileString("Install.ErrorPermissions");
            this.lnkPermissions.NavigateUrl = ResolveUrl("~/CMSMessages/ConfigurePermissions.aspx");
        }

        if ((Request.QueryString["siteid"] != null) && (Request.QueryString["siteid"] != ""))
        {
            siteId = Convert.ToInt32(Request.QueryString["siteid"]);
        }
        else
        {
            siteId = CMSContext.CurrentSite.SiteID;
        }
        SiteInfo siteInfo = SiteInfoProvider.GetSiteInfo(siteId);
        siteName = siteInfo.SiteName;
        lblFileCaption.Text = ResHelper.GetString("ExportSite.FileCaption");
        btnOK.Text = ResHelper.GetString("ExportSite.btnOK");
        btnFinall.Text = ResHelper.GetString("ExportSite.btnOK");
        lblSiteCaption.Text = ResHelper.GetString("ExportSite.SiteCaption");
        lblSiteName.Text = siteInfo.DisplayName;
        rfvRequiredFile.ErrorMessage = ResHelper.GetString("ExportSite.ErrorFileRequired");

        string sites = ResHelper.GetString("ExportSite.Sites");
        string title = ResHelper.GetString("ExportSite.Title");

        //initializes PageTitle
        string[,] pageTitleTabs = new string[2, 3];
        pageTitleTabs[0, 0] = sites;
        pageTitleTabs[0, 1] = "~/CMSSiteManager/Sites/site_list.aspx";
        pageTitleTabs[1, 0] = ResHelper.GetString("ExportSite.ExportSite");
        pageTitleTabs[1, 1] = "";
        ptExport.Breadcrumbs = pageTitleTabs;
        ptExport.TitleText = title;
        ptExport.TitleImage = "~/App_Themes/" + this.Theme + "/Images/CMSSiteManager/Sites/export.gif";
    }
    protected void ButtonOK_Click(object sender, EventArgs e)
    {
        if (txtFile.Text != "")
        {
            // if there is no zip extension in filename, adds it
            string filename = txtFile.Text.ToLower();
            int index = filename.IndexOf('.');
            if ((index == -1) || (filename.Substring(index + 1) != "zip"))
                filename += ".zip";
            SiteExportSettings settings = new SiteExportSettings(siteId, filename);

            settings.AddToExportTable("Data/siteinfo.xml", ExportSchema.SITEINFO_XML);
            settings.AddToExportTable("Data/settings.xml", ExportSchema.SETTINGS_XML);
            settings.AddToExportTable("Data/documenttypes.xml", ExportSchema.DOCUMENTTYPES_XML);
            settings.AddToExportTable("Data/users.xml", ExportSchema.USERS_XML);
            settings.AddToExportTable("Data/modules.xml", ExportSchema.MODULES_XML);
            settings.AddToExportTable("Data/roles.xml", ExportSchema.ROLES_XML);
            settings.AddToExportTable("Data/globalpermissions.xml", ExportSchema.PERMISSIONS_XML);
            settings.AddToExportTable("Data/cultures.xml", ExportSchema.CULTURES_XML);
            settings.AddToExportTable("Data/pagetemplates.xml", ExportSchema.PAGETEMPLATES_XML);
            settings.AddToExportTable("Data/documents.xml", ExportSchema.DOCUMENTS_XML);
            settings.AddToExportTable("Data/emailtemplates.xml", ExportSchema.EMAILTEMPLATES_XML);
            settings.AddToExportTable("Data/workflows.xml", ExportSchema.WORKFLOWS_XML);
            settings.AddToExportTable("Data/workflowhistories.xml", ExportSchema.WORKFLOWHISTORIES_XML);
            settings.AddToExportTable("Data/versionhistories.xml", ExportSchema.VERSIONHISTORIES_XML);
            //settings.AddToExportTable("Data/attachmenthistories.xml", ExportSchema.ATTACHMENTHISTORIES_XML);
            settings.AddToExportTable("Data/webparts.xml", ExportSchema.WEBPARTS_XML);
            settings.AddToExportTable("Data/formusercontrols.xml", ExportSchema.FORMUSERCONTROLS_XML);
            settings.AddToExportTable("Data/cssstylesheets.xml", ExportSchema.CSSSTYLESHEETS_XML);
            settings.AddToExportTable("Data/translationresources.xml", ExportSchema.RESOURCES_XML);
            settings.AddToExportTable("Data/attachments.xml", ExportSchema.ATTACHMENTS_XML);
            settings.AddToExportTable("Data/inlinecontrols.xml", ExportSchema.INLINECONTROLS_XML);
            settings.AddToExportTable("Data/relationships.xml", ExportSchema.RELATIONSHIPS_XML);
            settings.AddToExportTable("Data/bizforms.xml", ExportSchema.BIZFORMS_XML);
            settings.AddToExportTable("Data/newsletters.xml", ExportSchema.NEWSLETTERS_XML);
            settings.AddToExportTable("Data/newslettersubscribers.xml", ExportSchema.NEWSLETTERSUBSCRIBERS_XML);
            settings.AddToExportTable("Data/licensekeys.xml", ExportSchema.LICENSEKEYS_XML);
            settings.AddToExportTable("Data/scheduledtasks.xml", ExportSchema.SCHEDULEDTASKS_XML);

            try
            {
                // Copy attachment files
                ExportProvider.CopyAttachments(siteName, null);

                // Copy web parts to the temporary files
                ExportProvider.CopyWebParts(settings);

                // Copy form user controls to the temporary files
                ExportProvider.CopyFormUserControls(settings);

                // Copy inline controls to the temporary files
                ExportProvider.CopyInlineControls(settings);

                // Copy skin folders
                ExportProvider.CopySkinFolders(siteName, null);

                //Copy AppCode site folder
                ExportProvider.CopyAppCodeFolder(siteName, null);

                ExportProvider.ExportSite(settings, null);
                pnlForm.Visible = false;
                btnFinall.Visible = true;
                lblInfo.Text = ResHelper.GetString("ExportSite.MessageOK") + " " + MapPath(ExportProvider.EXPORT_PATH) + filename + ".";
            }
            catch (Exception ex)
            {
                lblError.Text = string.Format(ResHelper.GetString("ImportExportProvider.DetailedError"), ex.Message, ex.StackTrace);
            }
            finally
            {
                try
                {
                    ExportProvider.DeleteTemporaryFiles();
                }
                catch (TemporaryFilesDeletionException ex)
                {
                    if (lblError.Text != "")
                    {
                        lblError.Text += "<br/>" + ex.Message;
                    }
                    else
                    {
                        lblError.Text = ex.Message;
                    }
                }
            }
        }
    }


    protected void btnFinall_Click(object sender, EventArgs e)
    {
        Response.Redirect("~/CMSSiteManager/Sites/site_list.aspx");
    }
}
